@@ -3,7 +3,9 @@ use strict;
 use warnings;
 
 package Data::Conveyor;
-our $VERSION = '1.100870';
+BEGIN {
+  $Data::Conveyor::VERSION = '1.101690';
+}
 # ABSTRACT: Stage-based conveyor-belt-like ticket handling system
 
 # Marker package so sub-distros can use it in their Build.PL's 'requires'
@@ -20,7 +22,7 @@ Data::Conveyor - Stage-based conveyor-belt-like ticket handling system
 
 =head1 VERSION
 
-version 1.100870
+version 1.101690
 
 =head1 INSTALLATION
 
@@ -31,7 +33,7 @@ See perlmodinstall for information and options on installing Perl modules.
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org/Public/Dist/Display.html?Name=Data-Conveyor>.
+L<http://rt.cpan.org>.
 
 =head1 AVAILABILITY
 
