@@ -3,7 +3,9 @@ use strict;
 use warnings;
 
 package Data::Conveyor::App::Test::SIF::Unit;
-our $VERSION = '1.100870';
+BEGIN {
+  $Data::Conveyor::App::Test::SIF::Unit::VERSION = '1.101690';
+}
 # ABSTRACT: Stage-based conveyor-belt-like ticket handling system
 use Test::More;
 use parent 'Class::Scaffold::App::Test::YAMLDriven';
@@ -33,7 +35,7 @@ Data::Conveyor::App::Test::SIF::Unit - Stage-based conveyor-belt-like ticket han
 
 =head1 VERSION
 
-version 1.100870
+version 1.101690
 
 =head1 METHODS
 
@@ -50,7 +52,7 @@ See perlmodinstall for information and options on installing Perl modules.
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org/Public/Dist/Display.html?Name=Data-Conveyor>.
+L<http://rt.cpan.org>.
 
 =head1 AVAILABILITY
 
