@@ -3,7 +3,9 @@ use strict;
 use warnings;
 
 package Data::Conveyor::Charset::ViaHash;
-our $VERSION = '1.100870';
+BEGIN {
+  $Data::Conveyor::Charset::ViaHash::VERSION = '1.101690';
+}
 # ABSTRACT: Stage-based conveyor-belt-like ticket handling system
 
 use charnames ':full';
@@ -75,7 +77,7 @@ Data::Conveyor::Charset::ViaHash - Stage-based conveyor-belt-like ticket handlin
 
 =head1 VERSION
 
-version 1.100870
+version 1.101690
 
 =head1 METHODS
 
@@ -108,7 +110,7 @@ See perlmodinstall for information and options on installing Perl modules.
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org/Public/Dist/Display.html?Name=Data-Conveyor>.
+L<http://rt.cpan.org>.
 
 =head1 AVAILABILITY
 
