@@ -3,7 +3,9 @@ use strict;
 use warnings;
 
 package Data::Conveyor::Control::File;
-our $VERSION = '1.100870';
+BEGIN {
+  $Data::Conveyor::Control::File::VERSION = '1.101690';
+}
 # ABSTRACT: Stage-based conveyor-belt-like ticket handling system
 
 use parent 'Data::Conveyor::Control';
@@ -84,7 +86,7 @@ Data::Conveyor::Control::File - Stage-based conveyor-belt-like ticket handling s
 
 =head1 VERSION
 
-version 1.100870
+version 1.101690
 
 =head1 METHODS
 
@@ -101,7 +103,7 @@ See perlmodinstall for information and options on installing Perl modules.
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org/Public/Dist/Display.html?Name=Data-Conveyor>.
+L<http://rt.cpan.org>.
 
 =head1 AVAILABILITY
 
