@@ -3,7 +3,9 @@ use strict;
 use warnings;
 
 package Data::Conveyor::Environment;
-our $VERSION = '1.100870';
+BEGIN {
+  $Data::Conveyor::Environment::VERSION = '1.101690';
+}
 # ABSTRACT: Stage-based conveyor-belt-like ticket handling system
 
 # ptags: DCE
@@ -440,7 +442,7 @@ Data::Conveyor::Environment - Stage-based conveyor-belt-like ticket handling sys
 
 =head1 VERSION
 
-version 1.100870
+version 1.101690
 
 =head1 METHODS
 
@@ -509,7 +511,7 @@ See perlmodinstall for information and options on installing Perl modules.
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org/Public/Dist/Display.html?Name=Data-Conveyor>.
+L<http://rt.cpan.org>.
 
 =head1 AVAILABILITY
 
