@@ -3,7 +3,9 @@ use strict;
 use warnings;
 
 package Data::Conveyor::Mutex;
-our $VERSION = '1.100870';
+BEGIN {
+  $Data::Conveyor::Mutex::VERSION = '1.101690';
+}
 # ABSTRACT: Stage-based conveyor-belt-like ticket handling system
 
 use Sys::Hostname ();    # no import so we don't clash with our hostname()
@@ -200,7 +202,7 @@ Data::Conveyor::Mutex - Stage-based conveyor-belt-like ticket handling system
 
 =head1 VERSION
 
-version 1.100870
+version 1.101690
 
 =head1 METHODS
 
@@ -233,7 +235,7 @@ See perlmodinstall for information and options on installing Perl modules.
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org/Public/Dist/Display.html?Name=Data-Conveyor>.
+L<http://rt.cpan.org>.
 
 =head1 AVAILABILITY
 
