@@ -3,7 +3,9 @@ use strict;
 use warnings;
 
 package Data::Conveyor::Service::Result::Container;
-our $VERSION = '1.100870';
+BEGIN {
+  $Data::Conveyor::Service::Result::Container::VERSION = '1.101690';
+}
 # ABSTRACT: Stage-based conveyor-belt-like ticket handling system
 
 #
@@ -47,7 +49,7 @@ Data::Conveyor::Service::Result::Container - Stage-based conveyor-belt-like tick
 
 =head1 VERSION
 
-version 1.100870
+version 1.101690
 
 =head1 METHODS
 
@@ -68,7 +70,7 @@ See perlmodinstall for information and options on installing Perl modules.
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org/Public/Dist/Display.html?Name=Data-Conveyor>.
+L<http://rt.cpan.org>.
 
 =head1 AVAILABILITY
 
