@@ -3,7 +3,9 @@ use strict;
 use warnings;
 
 package Data::Conveyor::Service::Result::Tabular;
-our $VERSION = '1.100870';
+BEGIN {
+  $Data::Conveyor::Service::Result::Tabular::VERSION = '1.101690';
+}
 # ABSTRACT: Stage-based conveyor-belt-like ticket handling system
 
 use Text::Table;
@@ -80,7 +82,7 @@ Data::Conveyor::Service::Result::Tabular - Stage-based conveyor-belt-like ticket
 
 =head1 VERSION
 
-version 1.100870
+version 1.101690
 
 =head1 METHODS
 
@@ -109,7 +111,7 @@ See perlmodinstall for information and options on installing Perl modules.
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org/Public/Dist/Display.html?Name=Data-Conveyor>.
+L<http://rt.cpan.org>.
 
 =head1 AVAILABILITY
 
