@@ -3,7 +3,9 @@ use strict;
 use warnings;
 
 package Data::Conveyor::Stage::SingleTicket;
-our $VERSION = '1.100870';
+BEGIN {
+  $Data::Conveyor::Stage::SingleTicket::VERSION = '1.101690';
+}
 # ABSTRACT: Stage-based conveyor-belt-like ticket handling system
 
 # Base class for stages handling a single ticket (i.e., policy or delegation,
@@ -79,7 +81,7 @@ Data::Conveyor::Stage::SingleTicket - Stage-based conveyor-belt-like ticket hand
 
 =head1 VERSION
 
-version 1.100870
+version 1.101690
 
 =head1 METHODS
 
@@ -100,7 +102,7 @@ See perlmodinstall for information and options on installing Perl modules.
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org/Public/Dist/Display.html?Name=Data-Conveyor>.
+L<http://rt.cpan.org>.
 
 =head1 AVAILABILITY
 
