@@ -3,7 +3,9 @@ use strict;
 use warnings;
 
 package Data::Conveyor::Stage_TEST;
-our $VERSION = '1.100870';
+BEGIN {
+  $Data::Conveyor::Stage_TEST::VERSION = '1.101690';
+}
 # ABSTRACT: Stage-based conveyor-belt-like ticket handling system
 
 use Test::More;
@@ -27,7 +29,7 @@ Data::Conveyor::Stage_TEST - Stage-based conveyor-belt-like ticket handling syst
 
 =head1 VERSION
 
-version 1.100870
+version 1.101690
 
 =head1 INSTALLATION
 
@@ -38,7 +40,7 @@ See perlmodinstall for information and options on installing Perl modules.
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org/Public/Dist/Display.html?Name=Data-Conveyor>.
+L<http://rt.cpan.org>.
 
 =head1 AVAILABILITY
 
