@@ -3,7 +3,9 @@ use strict;
 use warnings;
 
 package Data::Conveyor::Storage::DBI;
-our $VERSION = '1.100870';
+BEGIN {
+  $Data::Conveyor::Storage::DBI::VERSION = '1.101690';
+}
 # ABSTRACT: Stage-based conveyor-belt-like ticket handling system
 
 use Error::Hierarchy::Internal::DBI::STH;
@@ -76,7 +78,7 @@ Data::Conveyor::Storage::DBI - Stage-based conveyor-belt-like ticket handling sy
 
 =head1 VERSION
 
-version 1.100870
+version 1.101690
 
 =head1 METHODS
 
@@ -105,7 +107,7 @@ See perlmodinstall for information and options on installing Perl modules.
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org/Public/Dist/Display.html?Name=Data-Conveyor>.
+L<http://rt.cpan.org>.
 
 =head1 AVAILABILITY
 
