@@ -3,7 +3,9 @@ use strict;
 use warnings;
 
 package Data::Conveyor::Storage::DBI::Core::Setup;
-our $VERSION = '1.100870';
+BEGIN {
+  $Data::Conveyor::Storage::DBI::Core::Setup::VERSION = '1.101690';
+}
 # ABSTRACT: Stage-based conveyor-belt-like ticket handling system
 
 # Utility storage methods encapsulating statements that all or most
@@ -82,7 +84,7 @@ Data::Conveyor::Storage::DBI::Core::Setup - Stage-based conveyor-belt-like ticke
 
 =head1 VERSION
 
-version 1.100870
+version 1.101690
 
 =head1 METHODS
 
@@ -111,7 +113,7 @@ See perlmodinstall for information and options on installing Perl modules.
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org/Public/Dist/Display.html?Name=Data-Conveyor>.
+L<http://rt.cpan.org>.
 
 =head1 AVAILABILITY
 
