@@ -3,7 +3,9 @@ use strict;
 use warnings;
 
 package Data::Conveyor::Storage::DBI::Postgres;
-our $VERSION = '1.100870';
+BEGIN {
+  $Data::Conveyor::Storage::DBI::Postgres::VERSION = '1.101690';
+}
 # ABSTRACT: Stage-based conveyor-belt-like ticket handling system
 
 # More specific superclass first. For example, Data::Storage defines a null
@@ -24,7 +26,7 @@ Data::Conveyor::Storage::DBI::Postgres - Stage-based conveyor-belt-like ticket h
 
 =head1 VERSION
 
-version 1.100870
+version 1.101690
 
 =head1 INSTALLATION
 
@@ -35,7 +37,7 @@ See perlmodinstall for information and options on installing Perl modules.
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org/Public/Dist/Display.html?Name=Data-Conveyor>.
+L<http://rt.cpan.org>.
 
 =head1 AVAILABILITY
 
