@@ -3,7 +3,9 @@ use strict;
 use warnings;
 
 package Data::Conveyor::Test::Ticket;
-our $VERSION = '1.100870';
+BEGIN {
+  $Data::Conveyor::Test::Ticket::VERSION = '1.101690';
+}
 # ABSTRACT: Stage-based conveyor-belt-like ticket handling system
 
 # Utilities for writing tests pertaining to tickets.
@@ -85,7 +87,7 @@ Data::Conveyor::Test::Ticket - Stage-based conveyor-belt-like ticket handling sy
 
 =head1 VERSION
 
-version 1.100870
+version 1.101690
 
 =head1 METHODS
 
@@ -106,7 +108,7 @@ See perlmodinstall for information and options on installing Perl modules.
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org/Public/Dist/Display.html?Name=Data-Conveyor>.
+L<http://rt.cpan.org>.
 
 =head1 AVAILABILITY
 
