@@ -3,7 +3,9 @@ use strict;
 use warnings;
 
 package Data::Conveyor::Ticket::Payload;
-our $VERSION = '1.100870';
+BEGIN {
+  $Data::Conveyor::Ticket::Payload::VERSION = '1.101690';
+}
 # ABSTRACT: Stage-based conveyor-belt-like ticket handling system
 
 # ptags: DCTP
@@ -244,7 +246,7 @@ sub get_all_exceptions {
         }
     }
     $result->items_push($self->common->exception_container->items);
-    $result;
+    $result->delete_duplicate_exceptions;  # returns $result
 }
 
 sub clear_all_exceptions {
@@ -324,7 +326,7 @@ Data::Conveyor::Ticket::Payload - Stage-based conveyor-belt-like ticket handling
 
 =head1 VERSION
 
-version 1.100870
+version 1.101690
 
 =head1 METHODS
 
@@ -417,7 +419,7 @@ See perlmodinstall for information and options on installing Perl modules.
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org/Public/Dist/Display.html?Name=Data-Conveyor>.
+L<http://rt.cpan.org>.
 
 =head1 AVAILABILITY
 
