@@ -3,7 +3,9 @@ use strict;
 use warnings;
 
 package Data::Conveyor::Transaction;
-our $VERSION = '1.100870';
+BEGIN {
+  $Data::Conveyor::Transaction::VERSION = '1.101690';
+}
 # ABSTRACT: Stage-based conveyor-belt-like ticket handling system
 
 # Base class for classes operating on transactions. Policy and delegation
@@ -55,7 +57,7 @@ Data::Conveyor::Transaction - Stage-based conveyor-belt-like ticket handling sys
 
 =head1 VERSION
 
-version 1.100870
+version 1.101690
 
 =head1 METHODS
 
@@ -84,7 +86,7 @@ See perlmodinstall for information and options on installing Perl modules.
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org/Public/Dist/Display.html?Name=Data-Conveyor>.
+L<http://rt.cpan.org>.
 
 =head1 AVAILABILITY
 
