@@ -3,7 +3,9 @@ use strict;
 use warnings;
 
 package Data::Conveyor::Value::LockType;
-our $VERSION = '1.100870';
+BEGIN {
+  $Data::Conveyor::Value::LockType::VERSION = '1.101690';
+}
 # ABSTRACT: Stage-based conveyor-belt-like ticket handling system
 use parent 'Data::Conveyor::Value::Enum';
 sub get_valid_values_list { our $cache_values ||= $_[0]->delegate->LO }
@@ -27,7 +29,7 @@ Data::Conveyor::Value::LockType - Stage-based conveyor-belt-like ticket handling
 
 =head1 VERSION
 
-version 1.100870
+version 1.101690
 
 =head1 METHODS
 
@@ -48,7 +50,7 @@ See perlmodinstall for information and options on installing Perl modules.
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org/Public/Dist/Display.html?Name=Data-Conveyor>.
+L<http://rt.cpan.org>.
 
 =head1 AVAILABILITY
 
