@@ -3,7 +3,9 @@ use strict;
 use warnings;
 
 package Data::Conveyor::YAML::Active::Payload::Instruction::Container;
-our $VERSION = '1.100870';
+BEGIN {
+  $Data::Conveyor::YAML::Active::Payload::Instruction::Container::VERSION = '1.101690';
+}
 # ABSTRACT: Stage-based conveyor-belt-like ticket handling system
 
 use YAML::Active qw/assert_arrayref array_activate/;
@@ -106,7 +108,7 @@ Data::Conveyor::YAML::Active::Payload::Instruction::Container - Stage-based conv
 
 =head1 VERSION
 
-version 1.100870
+version 1.101690
 
 =head1 METHODS
 
@@ -127,7 +129,7 @@ See perlmodinstall for information and options on installing Perl modules.
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org/Public/Dist/Display.html?Name=Data-Conveyor>.
+L<http://rt.cpan.org>.
 
 =head1 AVAILABILITY
 
