@@ -3,7 +3,9 @@ use strict;
 use warnings;
 
 package Data::Conveyor::YAML::Marshall::TicketNumber;
-our $VERSION = '1.100870';
+BEGIN {
+  $Data::Conveyor::YAML::Marshall::TicketNumber::VERSION = '1.101690';
+}
 # ABSTRACT: Stage-based conveyor-belt-like ticket handling system
 use YAML::Marshall 'ticket/number';
 use parent 'Class::Scaffold::YAML::Marshall';
@@ -28,7 +30,7 @@ Data::Conveyor::YAML::Marshall::TicketNumber - Stage-based conveyor-belt-like ti
 
 =head1 VERSION
 
-version 1.100870
+version 1.101690
 
 =head1 METHODS
 
@@ -45,7 +47,7 @@ See perlmodinstall for information and options on installing Perl modules.
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org/Public/Dist/Display.html?Name=Data-Conveyor>.
+L<http://rt.cpan.org>.
 
 =head1 AVAILABILITY
 
